Package: forcats
Title: Tools for Working with Categorical Variables (Factors)
Version: 1.0.1
Authors@R: c(
    person("Hadley", "Wickham", , "hadley@posit.co", role = c("aut", "cre")),
    person("Posit Software, PBC", role = c("cph", "fnd"),
           comment = c(ROR = "03wc8by49"))
  )
Description: Helpers for reordering factor levels (including moving
    specified levels to front, ordering by first appearance, reversing,
    and randomly shuffling), and tools for modifying factor levels
    (including collapsing rare levels into other, 'anonymising', and
    manually 'recoding').
License: MIT + file LICENSE
URL: https://forcats.tidyverse.org/,
        https://github.com/tidyverse/forcats
BugReports: https://github.com/tidyverse/forcats/issues
Depends: R (>= 4.1)
Imports: cli (>= 3.4.0), glue, lifecycle, magrittr, rlang (>= 1.0.0),
        tibble
Suggests: covr, dplyr, ggplot2, knitr, readr, rmarkdown, testthat (>=
        3.0.0), withr
VignetteBuilder: knitr
Config/Needs/website: tidyverse/tidytemplate
Config/testthat/edition: 3
Encoding: UTF-8
LazyData: true
RoxygenNote: 7.3.3
NeedsCompilation: no
Packaged: 2025-09-24 17:08:21 UTC; hadleywickham
Author: Hadley Wickham [aut, cre],
  Posit Software, PBC [cph, fnd] (ROR: <https://ror.org/03wc8by49>)
Maintainer: Hadley Wickham <hadley@posit.co>
Repository: CRAN
Date/Publication: 2025-09-25 05:10:20 UTC
Built: R 4.6.0; ; 2026-04-28 22:36:15 UTC; unix
