# Generated by roxygen2: do not edit by hand

S3method(as_factor,character)
S3method(as_factor,factor)
S3method(as_factor,logical)
S3method(as_factor,numeric)
export("%>%")
export(as_factor)
export(fct)
export(fct_anon)
export(fct_c)
export(fct_collapse)
export(fct_count)
export(fct_cross)
export(fct_drop)
export(fct_expand)
export(fct_explicit_na)
export(fct_infreq)
export(fct_inorder)
export(fct_inseq)
export(fct_lump)
export(fct_lump_lowfreq)
export(fct_lump_min)
export(fct_lump_n)
export(fct_lump_prop)
export(fct_match)
export(fct_na_level_to_value)
export(fct_na_value_to_level)
export(fct_other)
export(fct_recode)
export(fct_relabel)
export(fct_relevel)
export(fct_reorder)
export(fct_reorder2)
export(fct_rev)
export(fct_shift)
export(fct_shuffle)
export(fct_unify)
export(fct_unique)
export(first2)
export(last2)
export(lvls_expand)
export(lvls_reorder)
export(lvls_revalue)
export(lvls_union)
import(rlang)
importFrom(glue,glue)
importFrom(lifecycle,deprecated)
importFrom(magrittr,"%>%")
importFrom(stats,median)
